@@ -14,7 +14,7 @@ class DictToJson(object):
                 'class':'sheet',
                 'title':'导图1',
                 'topicPositioning':'fixed',
-                'rootTopic':''
+                'rootTopic':'',
                 }]
         
         self.topic = {
@@ -23,6 +23,13 @@ class DictToJson(object):
                 "structureClass":"org.xmind.ui.map.unbalanced",
                 "children":''
                 } 
+        self.theme = {
+                "subTopic":{
+                    "properties":{
+                        "for:text-agign":"left"
+                        }
+                    }
+                }
     def create_attach(self, in_dict):
         attach = {
                 "children":{},
@@ -75,6 +82,7 @@ class DictToJson(object):
 
     def start(self, total_dict):
         self.root[0]['rootTopic'] = self.topic
+        #self.root[0]['theme'] = self.theme
         self.topic['title'] = total_dict['title']
         #del total_dict['title']
 
