@@ -50,8 +50,11 @@ class MarkdownToDict(object):
         elif line[0] != ' ' and line[0] != "*":
             return '',''
         else:
-            num = line.split('* ')[0].count(' ')/4 + 4
-            title = line[line.find("* ")+2:]
+            if line.find("* ") < 0:
+                return 'add', line
+            else:
+                num = line.split('* ')[0].count(' ')/4 + 4
+                title = line[line.find("* ")+2:]
         return int(num), title
 
     def get_tree_node(self, md_file):
@@ -60,6 +63,8 @@ class MarkdownToDict(object):
         end_line = "*XMind: ZEN - Trial Version*"
         
         fd = open(md_file,'r')
+        last_title = ''
+        last_tabs = 'init'
         while True:
             line = fd.readline()
             #print(line)
@@ -71,10 +76,17 @@ class MarkdownToDict(object):
             if line == '':
                 continue
             tabs, title = self.get_count(line)
-            #print(tabs)
             if tabs == '':
                 continue
-            inserter(title, tabs)
+            if tabs == 'add':
+                #print(11111111)
+                last_title += '\n' + title
+            else:
+                if last_tabs != 'init':
+                    #print(last_title, last_tabs)
+                    inserter(last_title, last_tabs)
+                last_title = title
+                last_tabs = tabs
         fd.close()
         return tree
 
